@@ -1,7 +1,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2005-2020. All Rights Reserved.
+%% Copyright Ericsson AB 2005-2021. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -78,7 +78,7 @@
 	  mode,			 % read | write  (=from or to buffer by user)
 	  crypto_state,
 	  crypto_fun,            % For encode or decode depending on the mode field
-	  size = 0,		 % # bytes "before" the current buffer for the postion call
+	  size = 0,		 % # bytes "before" the current buffer for the position call
 
 	  chunksize,		 % The size of the chunks to be sent or received
 	  enc_text_buf = <<>>,	 % Encrypted text
@@ -135,7 +135,8 @@ start_channel(Dest) ->
                    )
                    -> {ok,pid(),ssh:connection_ref()} | {error,reason()} .
 
-start_channel(Cm, UserOptions) when is_pid(Cm) ->
+start_channel(Cm, UserOptions0) when is_pid(Cm) ->
+    UserOptions = legacy_timeout(UserOptions0),
     Timeout = proplists:get_value(timeout, UserOptions, infinity),
     {_SshOpts, ChanOpts, SftpOpts} = handle_options(UserOptions),
     WindowSize = proplists:get_value(window_size, ChanOpts, ?XFER_WINDOW_SIZE),
@@ -158,7 +159,8 @@ start_channel(Cm, UserOptions) when is_pid(Cm) ->
 	    Error
     end;
 
-start_channel(Dest, UserOptions) ->
+start_channel(Dest, UserOptions0) ->
+    UserOptions = legacy_timeout(UserOptions0),
     {SshOpts, ChanOpts, SftpOpts} = handle_options(UserOptions),
     case ssh:is_host(Dest, SshOpts) of
         true ->
@@ -167,9 +169,7 @@ start_channel(Dest, UserOptions) ->
         false ->
             %% No, it is probably not a Host, must be a socket
             Socket = Dest,
-            Timeout =   % A mixture of ssh:connect and ssh_sftp:start_channel:
-                proplists:get_value(connect_timeout, SshOpts,
-                                    proplists:get_value(timeout, SftpOpts, infinity)),
+            Timeout = proplists:get_value(connect_timeout, SshOpts, infinity),
             case ssh:connect(Socket, SshOpts, Timeout) of
                 {ok,Cm} ->
                     case start_channel(Cm, ChanOpts ++ SftpOpts) of
@@ -193,15 +193,10 @@ start_channel(Dest, UserOptions) ->
                    )
                    -> {ok,pid(),ssh:connection_ref()} | {error,reason()}.
 
-start_channel(Host, Port, UserOptions) ->
+start_channel(Host, Port, UserOptions0) ->
+    UserOptions = legacy_timeout(UserOptions0),
+    Timeout = proplists:get_value(connect_timeout, UserOptions, infinity),
     {SshOpts, _ChanOpts, _SftpOpts} = handle_options(UserOptions),
-    Timeout =   % A mixture of ssh:connect and ssh_sftp:start_channel:
-        case proplists:get_value(connect_timeout, UserOptions) of
-            undefined ->
-                proplists:get_value(timeout, UserOptions, infinity);
-            TO ->
-                TO
-        end,
     case ssh:connect(Host, Port, SshOpts, Timeout) of
 	{ok, Cm} ->
             case start_channel(Cm, UserOptions) of
@@ -1228,6 +1223,21 @@ terminate(_Reason, State) ->
 %%====================================================================
 %% Internal functions
 %%====================================================================
+legacy_timeout(UserOptions) ->
+    %% Make both connect_timeout and timeout defined if exactly one of them is defined:
+    case {proplists:get_value(connect_timeout, UserOptions),
+          proplists:get_value(timeout, UserOptions)} of
+        {undefined, undefined} ->
+            UserOptions;
+        {undefined, TO} ->
+            [{connect_timeout,TO} | UserOptions];
+        {TO, undefined} ->
+            [{timeout,TO} | UserOptions];
+        {_, _} ->
+            UserOptions
+    end.
+
+
 handle_options(UserOptions) ->
     handle_options(UserOptions, [], [], []).
 
@@ -1572,7 +1582,7 @@ erase_handle(Handle, State) ->
     State#state{inf = FI}.
 
 %%
-%% Caluclate a integer offset
+%% Calculate a integer offset
 %%
 lseek_position(Handle, Pos, State) ->
     case maps:find(Handle, State#state.inf) of
@@ -1709,7 +1719,7 @@ do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
 			   chunksize = undefined
 			  })
   when size(EncBuf0) > 0 ->
-    %% We have (at least) one decodable byte waiting for decodeing.
+    %% We have (at least) one decodable byte waiting for decoding.
     {ok,DecodedBin,B} = apply_crypto(EncBuf0, B0),
     do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
 		    B#bufinf{plain_text_buf = <<PlainBuf0/binary, DecodedBin/binary>>,
@@ -1722,7 +1732,7 @@ do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
 			   chunksize = ChunkSize0
 			  })
   when size(EncBuf0) >= ChunkSize0 ->
-    %% We have (at least) one chunk of decodable bytes waiting for decodeing.
+    %% We have (at least) one chunk of decodable bytes waiting for decoding.
     <<ToDecode:ChunkSize0/binary, EncBuf/binary>> = EncBuf0,
     {ok,DecodedBin,B} = apply_crypto(ToDecode, B0),
     do_the_read_buf(Pid, SftpHandle, WantedLen, Packet, FileOpTimeout,
